@@ -664,10 +664,9 @@ VR_summ2(Sint *n0, Sint *p0, Sint *q0, Sdata *Z, Sint *na)
     *na = j + 1;
 }
 
-/*
 #include "R_ext/Rdynload.h"
 
-R_CMethodDef CEntries[] = {
+static const R_CMethodDef CEntries[] = {
     {"VR_dfunc", (DL_FUNC) &VR_dfunc, 3},
     {"VR_dovm", (DL_FUNC) &VR_dovm, 11},
     {"VR_nnHessian", (DL_FUNC) &VR_nnHessian, 5},
@@ -682,4 +681,3 @@ void R_init_nnet(DllInfo *dll)
 {
     R_registerRoutines(dll, CEntries, NULL, NULL, NULL);
 }
-*/
